# Changelog

## 0.0.2 (2025-11-27)

Full Changelog: [v0.0.1...v0.0.2](https://github.com/indicesio/indices-python/compare/v0.0.1...v0.0.2)

### Features

* **api:** config updates ([88eadb3](https://github.com/indicesio/indices-python/commit/88eadb3d17bb0ada31c4fcd6fed1838d47916e81))
* **api:** update openapi spec (v1beta, etc) ([546f449](https://github.com/indicesio/indices-python/commit/546f44918e9b02c6cda3abcab760f2d954e955ec))


### Bug Fixes

* **client:** close streams without requiring full consumption ([959e13b](https://github.com/indicesio/indices-python/commit/959e13b69b92580d77aaa31f33adc3abccb50589))
* compat with Python 3.14 ([a37a195](https://github.com/indicesio/indices-python/commit/a37a1954165cc58e4b2f48cf8fb071455b191900))
* **compat:** update signatures of `model_dump` and `model_dump_json` for Pydantic v1 ([b4d1653](https://github.com/indicesio/indices-python/commit/b4d165320434b8447770e0cb417be404d21e0559))


### Chores

* add Python 3.14 classifier and testing ([541071b](https://github.com/indicesio/indices-python/commit/541071bf220a04ad50593691d34f2d3a96848f5f))
* **internal/tests:** avoid race condition with implicit client cleanup ([844f1fb](https://github.com/indicesio/indices-python/commit/844f1fb36c363c4e60d05bd311ed96115db3244c))
* **internal:** grammar fix (it's -&gt; its) ([49e8427](https://github.com/indicesio/indices-python/commit/49e8427b5299817d6bc5a06cec3deed1f164cbc0))
* **package:** drop Python 3.8 support ([daf5eee](https://github.com/indicesio/indices-python/commit/daf5eee6e9478719c680e775530b436b90870a84))

## 0.0.1 (2025-10-20)

Full Changelog: [v0.0.1...v0.0.1](https://github.com/indicesio/indices-python/compare/v0.0.1...v0.0.1)

### Features

* **api:** manual updates ([bd1ba01](https://github.com/indicesio/indices-python/commit/bd1ba01702edb85b98309a8f4b8b626c7a4f34f1))


### Chores

* update SDK settings ([29395f4](https://github.com/indicesio/indices-python/commit/29395f42da941577e78d2e18f310dfdfac11e044))
* update SDK settings ([7e79028](https://github.com/indicesio/indices-python/commit/7e79028fed7be3b520ff233352d28d0b9518d2ab))
